/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2022 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.16.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for MSP430F5529 running on TS430PN80USB evalboard
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include <msp430x552x.h>

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (0)        // LED1 on TS430PN80USB evalboard
#define LED1_BIT      (1)        // LED2 not assembled on evalboard

#define LED_PORT_DIR  (P8DIR)    // LEDS are connected to Port 8
#define LED_PORT_OUT  (P8OUT)

#define LED_MASK_ALL  ((1 << LED0_BIT) | (1 << LED1_BIT))
#define LED_MASK_LED0 (1 << LED0_BIT)
#define LED_MASK_LED1 (1 << LED1_BIT)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LED_PORT_DIR = LED_MASK_ALL;               // Switch Port to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    LED_PORT_OUT |= LED_MASK_LED0;           // Switch on LED 0
  }
  if  (Index == 1) {
    LED_PORT_OUT |= LED_MASK_LED1;           // Switch on LED 1
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    LED_PORT_OUT &= ~LED_MASK_LED0;          // Switch off LED 0
  }
  if (Index == 1) {
    LED_PORT_OUT &= ~LED_MASK_LED1;          // Switch off LED 1
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    LED_PORT_OUT ^= LED_MASK_LED0;           // Toggle LED 0
  }
  if (Index == 1) {
    LED_PORT_OUT ^= LED_MASK_LED1;           // Toggle LED 1
  }
}

/****** End Of File *************************************************/
