/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2022 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.16.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for MSP430FG4619 and MSP-TS430PZ100 eval board
*/

#include "BSP.h"
#include "io430xG46x.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define _LED0_BIT      (1)        /* LED D1 on MSP-TS430 Eval board */
#define _LED1_BIT      (2)        /* LED not assembled on Eval board*/

#define _LED_PORT_DIR  (P5DIR)    /* LEDS are connected to Port 5   */
#define _LED_PORT_OUT  (P5OUT)

#define _LED_MASK_ALL  (1 << _LED0_BIT)
#define _LED_MASK_LED0 (1 << _LED0_BIT)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  _LED_PORT_DIR = _LED_MASK_ALL;           /* Switch Port to output */
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT |= _LED_MASK_LED0;          /* Switch on LED 0  */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT &= ~_LED_MASK_LED0;         /* Switch off LED 0 */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT ^= _LED_MASK_LED0;
  }
}

/*************************** End of file ****************************/
