/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2022 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.16.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for MSP430F5438 and MSP-TS430PZ100F54 eval board
*/

#include "BSP.h"
#include <msp430.h>

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define _LED0_BIT      (0)        // LED1 on EXP430 Eval board
#define _LED1_BIT      (1)        // LED2 on EXP430 Eval board

#define _LED_PORT_DIR  (PADIR)    // LEDS are connected to Port A
#define _LED_PORT_OUT  (PAOUT)

#define _LED_MASK_LED0 (1 << _LED0_BIT)
#define _LED_MASK_LED1 (1 << _LED1_BIT)
#define _LED_MASK_ALL  (_LED_MASK_LED0 | _LED_MASK_LED1)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  _LED_PORT_DIR = _LED_MASK_ALL;       // Switch Port to output
  _LED_PORT_OUT = _LED_MASK_ALL;       // Switch LEDs on initially
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT |= _LED_MASK_LED0;   // Switch on LED 0
  } else if (Index == 1) {
    _LED_PORT_OUT |= _LED_MASK_LED1;   // Switch on LED 1
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT &= ~_LED_MASK_LED0;  // Switch off LED 0
  } else if (Index == 1) {
    _LED_PORT_OUT &= ~_LED_MASK_LED1;  // Switch off LED 0
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    _LED_PORT_OUT ^= _LED_MASK_LED0;   // Toggle LED 0
  } else if (Index == 1) {
    _LED_PORT_OUT ^= _LED_MASK_LED1;   // Toggle LED 0
  }
}

/*************************** End of file ****************************/
